@@ -1,6 +1,6 @@
 package Class::PObject::Test::Types;
 
-# Types.pm,v 1.5 2003/11/06 01:21:10 sherzodr Exp
+# $Id$
 
 use strict;
 #use diagnostics;
@@ -8,7 +8,7 @@ use Test::More;
 use vars ('$VERSION', '@ISA');
 
 BEGIN {
-    plan(tests => 41);
+    plan(tests => 46);
     use_ok("Class::PObject");
     use_ok("Class::PObject::Test");
     use_ok("Class::PObject::Type");
@@ -125,6 +125,26 @@ sub run {
     ok($u->save == $id, $u->errstr);
 
 
+	################
+	#
+	# Checking col. member functions (inside Type.pm)
+	#
+	my $substr = $u->name()->substr(0, 6);
+	ok($substr eq "Sherzo", $substr);
+
+    my $lcfirst = $u->name()->lcfirst();
+    ok($lcfirst eq 'sherzod Ruzmetov (e)');
+
+    my $ucfirst = $u->name()->ucfirst();
+    ok($ucfirst eq 'Sherzod Ruzmetov (e)');
+
+    my $lc = $u->name()->lc();
+    ok($lc eq 'sherzod ruzmetov (e)');
+
+    my $uc = $u->name()->uc();
+    ok($uc eq 'SHERZOD RUZMETOV (E)');
+
+
     ################
     #
     # Checking load(\%terms, undef) syntax
